@@ -1,6 +1,3 @@
-library(bbw)
-context("Blocking weighted bootstrap")
-
 boot <- bootBW(x = indicatorsHH,
                w = villageData,
                statistic = bootClassic,
@@ -33,3 +30,15 @@ test_that("boot row number is replicates", {
 test_that("boot column number is length of params", {
   expect_equal(ncol(boot), 4)
 })
+
+test_that("bbw errors/message are as expected", {
+  expect_error(
+    bootBW(x = indicatorsHH,
+      w = villageData,
+      statistic = bootClassic,
+      params = c("anc1", "anc2", "anc3", "anc4"),
+      outputColumns = c("anc1", "anc2", "anc3"),
+      replicates = 9
+    )
+  )
+})
\ No newline at end of file
