@@ -1,12 +1,9 @@
-library(bbw)
-context("Recode")
-
 var <- 1:5
 recodes <- "1:2=1;3:4=2;else=NA"
 x <- recode(var = var, recodes = recodes)
 
 test_that("x is numeric", {
-  expect_is(x, "numeric")
+  expect_type(x, "double")
 })
 
 test_that("recode is c(1, 1, 2, 2, NA)", {
@@ -22,7 +19,7 @@ recodes <- "'a'=1;'b'=2;else=NA"
 x <- recode(var = var, recodes = recodes)
 
 test_that("x is numeric", {
-  expect_is(x, "numeric")
+  expect_type(x, "double")
 })
 
 test_that("recode is c(1, 2, NA, NA, NA)", {
@@ -32,3 +29,12 @@ test_that("recode is c(1, 2, NA, NA, NA)", {
   expect_true(is.na(x[4]))
   expect_true(is.na(x[5]))
 })
+
+test_that("recode handles factors as expected", {
+  var <- factor(letters[1:5])
+  recodes <- "'a'=1;'b'=2;else=NA"
+  x <- recode(var = var, recodes = recodes)
+
+  expect_type(x, "integer")
+  expect_true(class(x) == "factor")
+})
